==> 1.0.12.tar.gz: lib/src/characteristics/characteristics.dart <==
// ignore_for_file: public_member_api_docs, constant_identifier_names, lines_longer_than_80_chars

enum Characteristics {
  LEAD_STATE,
  ONE_CHANNEL,
  TAP_PHYSICAL_BUTTON,
  RESPIRATION_ONE_CHANNEL,
  PULSE_OXIMETER_CONTINUOUS,
  PULSE_OXIMETER_CONFIGURATION,
  BODY_TEMPERATURE,
  DEVICE_CONTROL_POINT,
  DEVICE_CONTROL_CONFIRM,
  BATTERY_LEVEL,
  PRODUCT_MANUFACTURER,
  FIRMWARE_VERSION,
  SERIAL_NUMBER,
}

class UUID {
  // https://healthrian.atlassian.net/wiki/spaces/WEAR/pages/1902706689/F+W+wearCardioT
  static const characteristic = {
    Characteristics.LEAD_STATE: '00002C00-0000-1000-8000-00805F9B34FB',
    Characteristics.ONE_CHANNEL: '00002C01-0000-1000-8000-00805F9B34FB',
    Characteristics.TAP_PHYSICAL_BUTTON: '',
    Characteristics.RESPIRATION_ONE_CHANNEL: ' 00002C11-0000-1000-8000-00805F9B34FB',
    Characteristics.PULSE_OXIMETER_CONTINUOUS: '00002A5F-0000-1000-8000-00805F9B34FB',
    Characteristics.PULSE_OXIMETER_CONFIGURATION: '00002A60-0000-1000-8000-00805F9B34FB',
    Characteristics.BODY_TEMPERATURE: '',
    Characteristics.DEVICE_CONTROL_POINT: '00002CF0-0000-1000-8000-00805F9B34FB',
    Characteristics.DEVICE_CONTROL_CONFIRM: '00002CF1-0000-1000-8000-00805F9B34FB',
    Characteristics.BATTERY_LEVEL: '00002A19-0000-1000-8000-00805F9B34FB',
    Characteristics.PRODUCT_MANUFACTURER: '00002A29-0000-1000-8000-00805F9B34FB',
    Characteristics.FIRMWARE_VERSION: '00002A26-0000-1000-8000-00805F9B34FB',
    Characteristics.SERIAL_NUMBER: '00002A25-0000-1000-8000-00805F9B34FB',
  };
}

==> 1.0.17.tar.gz: lib/src/characteristics/characteristics.dart <==
// ignore_for_file: public_member_api_docs, constant_identifier_names, lines_longer_than_80_chars

enum Characteristics {
  LEAD_STATE,
  ONE_CHANNEL,
  TAP_PHYSICAL_BUTTON,
  RESPIRATION_ONE_CHANNEL,
  PULSE_OXIMETER_CONTINUOUS,
  PULSE_OXIMETER_CONFIGURATION,
  BODY_TEMPERATURE,
  DEVICE_CONTROL_POINT,
  DEVICE_CONTROL_CONFIRM,
  BATTERY_LEVEL,
  PRODUCT_MANUFACTURER,
  FIRMWARE_VERSION,
  SERIAL_NUMBER,
}

class UUID {
  /// https://healthrian.atlassian.net/wiki/spaces/WEAR/pages/1902706689/F+W+wearCardioT
  static const characteristic = {
    Characteristics.LEAD_STATE: '00002C00-0000-1000-8000-00805F9B34FB',
    Characteristics.ONE_CHANNEL: '00002C01-0000-1000-8000-00805F9B34FB',
    Characteristics.TAP_PHYSICAL_BUTTON: '',
    Characteristics.RESPIRATION_ONE_CHANNEL: ' 00002C11-0000-1000-8000-00805F9B34FB',
    Characteristics.PULSE_OXIMETER_CONTINUOUS: '00002A5F-0000-1000-8000-00805F9B34FB',
    Characteristics.PULSE_OXIMETER_CONFIGURATION: '00002A60-0000-1000-8000-00805F9B34FB',
    Characteristics.BODY_TEMPERATURE: '',
    Characteristics.DEVICE_CONTROL_POINT: '00002CF0-0000-1000-8000-00805F9B34FB',
    Characteristics.DEVICE_CONTROL_CONFIRM: '00002CF1-0000-1000-8000-00805F9B34FB',
    Characteristics.BATTERY_LEVEL: '00002A19-0000-1000-8000-00805F9B34FB',
    Characteristics.PRODUCT_MANUFACTURER: '00002A29-0000-1000-8000-00805F9B34FB',
    Characteristics.FIRMWARE_VERSION: '00002A26-0000-1000-8000-00805F9B34FB',
    Characteristics.SERIAL_NUMBER: '00002A25-0000-1000-8000-00805F9B34FB',
  };
}
